document.addEventListener('DOMContentLoaded', function () {
    const canvas = document.getElementById('canvas');
    const moduleButtons = document.querySelectorAll('.sidebar .module-selector-btn');

    /** 🔹 Allow clicking modules in sidebar to add them */
    moduleButtons.forEach(button => {
        button.addEventListener('click', function () {
            addModuleToCanvas(button.getAttribute('data-module'));
        });

        button.addEventListener('dragstart', handleDragStart);
    });

    /** 🔹 Drag & Drop Functionality */
    canvas.addEventListener('dragover', handleDragOver);
    canvas.addEventListener('drop', handleDrop);

    function handleDragStart(e) {
        e.dataTransfer.setData('text/plain', e.target.getAttribute('data-module'));
        e.dataTransfer.effectAllowed = 'copy';
    }

    function handleDragOver(e) {
        e.preventDefault();
        e.dataTransfer.dropEffect = 'copy';
    }

    function handleDrop(e) {
        e.preventDefault();
        const moduleType = e.dataTransfer.getData('text/plain');
        addModuleToCanvas(moduleType, e.clientY);
    }

    /** ✅ Function to Add Module to Canvas (Fixes Duplicate Text) */
    function addModuleToCanvas(moduleType, dropY = null) {
        if (!moduleMarkup[moduleType]) {
            console.warn(`No markup found for module type: ${moduleType}`);
            return;
        }

        // Ensure correct module rendering (Prevents duplicate content)
        const tempDiv = document.createElement('div');
        tempDiv.innerHTML = moduleMarkup[moduleType].trim();
        const moduleEl = tempDiv.firstElementChild;

        if (!moduleEl) {
            console.error(`Error creating module: ${moduleType}`);
            return;
        }

        // ✅ Ensure it has ONLY the module-preview class
        moduleEl.classList.add('module-preview');

        // ✅ Remove any duplicate previews inside module content
        const previewElement = moduleEl.querySelector('.module-preview');
        if (previewElement) {
            previewElement.remove(); // Remove unnecessary extra elements
        }

        /** ✅ Attach Delete Button */
        const deleteIcon = document.createElement('div');
        deleteIcon.className = 'delete-icon';
        deleteIcon.innerHTML = '&times;';
        deleteIcon.onclick = function () {
            moduleEl.remove();
            updatePageNumbers();
        };
        moduleEl.appendChild(deleteIcon);

        /** ✅ Insert module at correct drop location */
        if (dropY !== null) {
            let inserted = false;
            const modules = Array.from(canvas.querySelectorAll('.module-preview'));
            for (let mod of modules) {
                const rect = mod.getBoundingClientRect();
                if (dropY < rect.top + rect.height / 2) {
                    canvas.insertBefore(moduleEl, mod);
                    inserted = true;
                    break;
                }
            }
            if (!inserted) {
                canvas.appendChild(moduleEl);
            }
        } else {
            canvas.appendChild(moduleEl);
        }

        /** ✅ Ensure newly added module is selectable */
        clearSelections();
        moduleEl.classList.add('selected');
        loadModuleSettings(moduleEl, moduleType);

        updatePageNumbers();
    }

    /** 🔹 Handle Clicks to Select Modules & Load Settings */
    canvas.addEventListener('click', function (e) {
        const clickedModule = e.target.closest('.module-preview');
        if (clickedModule) {
            clearSelections();
            clickedModule.classList.add('selected');

            const moduleType = clickedModule.getAttribute('data-module');
            loadModuleSettings(clickedModule, moduleType);
        }
    });

    function clearSelections() {
        document.querySelectorAll('.module-preview').forEach(m => m.classList.remove('selected'));
    }

    /** 🔹 Dynamically Update Page Numbers for PageBreakModule */
    function updatePageNumbers() {
        const pageBreaks = document.querySelectorAll('.canvas .page-break-module .dynamic-page-number');
        pageBreaks.forEach((elem, index) => {
            elem.textContent = index + 1;
        });
    }

    // Observe the canvas for changes & update page numbers dynamically
    const observer = new MutationObserver(updatePageNumbers);
    observer.observe(canvas, { childList: true, subtree: true });

    // Initial update on page load
    updatePageNumbers();
});
