<?php
// modules/LikertScale.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class LikertScale {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        // Generate a unique ID if none is provided
        $this->instanceId = $instanceId ?: uniqid('likertScale_');

        // Merge default settings with any passed in
        $this->settings = array_merge([
            'buttonName'       => 'Likert Scale',
            'mainHeading'      => 'Consequences of Unforgiveness',
            'statementColumn'  => 'Attitudes',
            'scaleColumn'      => 'Intensity of this attitude in my heart',

            // Default statements (you can add more if needed)
            'statement1'       => 'Anger',
            'statement2'       => 'Depression',
            'statement3'       => 'Distrust of Others',
            'statement4'       => 'Jealousy',
        ], $settings);
    }

    /**
     * Renders the module as a Likert scale table with a main heading,
     * a header row, and four default rows for statements.
     */
    public function render() {
        ob_start(); ?>
        
        <div class="module-preview likert-scale-module"
             data-module="LikertScale"
             data-module-id="<?php echo esc($this->instanceId); ?>">

            <!-- Inline CSS for styling the Likert scale cells -->
            <style>
                .likert-scale-container {
                    max-width: 900px;
                    margin: 0 auto;
                    border: 1px solid #ccc;
                    border-radius: 8px;
                    overflow: hidden;
                    font-family: Arial, sans-serif;
                }
                .table-main-heading {
                    background: #0d5a82;
                    color: #fff;
                    text-align: center;
                    font-size: 18px;
                    padding: 12px;
                    font-weight: bold;
                }
                table.likert-scale-table {
                    width: 100%;
                    border-collapse: collapse;
                }
                table.likert-scale-table thead th {
                    background: #f2d180;
                    text-align: center;
                    padding: 12px;
                    font-size: 16px;
                    border-bottom: 2px solid #ccc;
                }
                table.likert-scale-table tbody tr {
                    border-bottom: 1px solid #eee;
                }
                table.likert-scale-table tbody td {
                    padding: 12px;
                    text-align: center;
                }
                .statement-label {
                    text-align: left;
                    font-weight: bold;
                    width: 30%;
                }
                
                /* 
                   Row container to keep rating cells together
                   without wrapping or spacing. 
                */
                .likert-row {
                    white-space: nowrap; /* Prevents cells from wrapping */
                }
                
                /*
                   Each cell is 70px wide, no margin between them.
                   We remove the right border on all but the last cell
                   so adjacent cells share a single border.
                */
                .likert-cell {
                    display: inline-block;
                    width: 70px;
                    border: 1px solid #ccc;
                    text-align: center;
                    vertical-align: middle;
                    margin: 0;
                    border-radius: 2px;
                    overflow: hidden;
                    cursor: pointer;
                    box-sizing: border-box;
                }
                .likert-cell:not(:last-of-type) {
                    border-right: none; /* So adjacent cells appear to touch */
                }
                
                /* Top half: number with light-blue background */
                .likert-value {
                    background: #d2e5ef;
                    color: #0d5a82;
                    font-weight: bold;
                    font-size: 14px;
                    padding: 8px 0;
                }
                /* Bottom half: radio button on white background */
                .likert-radio {
                    background: #fff;
                    padding: 6px 0;
                }
                /* Hover effect on the top half */
                .likert-cell:hover .likert-value {
                    background: #c5d9e4;
                }
                /* Optional: style the radio button itself */
                .likert-cell input[type="radio"] {
                    cursor: pointer;
                }
            </style>

            <div class="likert-scale-container">
                <!-- Main Heading -->
                <div class="table-main-heading">
                    <?php echo esc($this->settings['mainHeading']); ?>
                </div>

                <table class="likert-scale-table">
                    <thead>
                        <tr>
                            <th><?php echo esc($this->settings['statementColumn']); ?></th>
                            <th><?php echo esc($this->settings['scaleColumn']); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <!-- Row 1 -->
                        <tr>
                            <td class="statement-label">
                                <?php echo esc($this->settings['statement1']); ?>
                            </td>
                            <td>
                                <div class="likert-row">
                                    <?php $this->renderScale(1); ?>
                                </div>
                            </td>
                        </tr>
                        <!-- Row 2 -->
                        <tr>
                            <td class="statement-label">
                                <?php echo esc($this->settings['statement2']); ?>
                            </td>
                            <td>
                                <div class="likert-row">
                                    <?php $this->renderScale(2); ?>
                                </div>
                            </td>
                        </tr>
                        <!-- Row 3 -->
                        <tr>
                            <td class="statement-label">
                                <?php echo esc($this->settings['statement3']); ?>
                            </td>
                            <td>
                                <div class="likert-row">
                                    <?php $this->renderScale(3); ?>
                                </div>
                            </td>
                        </tr>
                        <!-- Row 4 -->
                        <tr>
                            <td class="statement-label">
                                <?php echo esc($this->settings['statement4']); ?>
                            </td>
                            <td>
                                <div class="likert-row">
                                    <?php $this->renderScale(4); ?>
                                </div>
                            </td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
        
        <?php
        return ob_get_clean();
    }

    /**
     * Renders a row of 0-5 cells, each split into:
     * - Top half: The numeric label
     * - Bottom half: A radio button
     *
     * $rowIndex ensures each row has a unique radio group name.
     */
    private function renderScale($rowIndex) {
        // Make each row's radio buttons a unique group
        $groupName = 'likert_' . $this->instanceId . '_row' . $rowIndex;

        for ($i = 0; $i <= 5; $i++): ?>
<label class="likert-cell">
    <div class="likert-value"><?php echo $i; ?></div>
    <div class="likert-radio">
        <input type="radio" name="<?php echo esc($groupName); ?>" value="<?php echo $i; ?>">
    </div>
</label><?php
        endfor;
    }

    /**
     * Renders the sidebar button for module selection.
     */
    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="LikertScale">'
             . esc($this->settings['buttonName'])
             . '</button>';
    }

    /**
     * Renders the settings panel for this module.
     */
    public function renderSettings() {
        ob_start(); ?>
        
        <div class="form-group">
            <label for="mainHeading">Main Table Heading:</label>
            <input type="text" id="mainHeading" data-update="mainHeading"
                   value="<?php echo esc($this->settings['mainHeading']); ?>">
        </div>

        <div class="form-group">
            <label for="statementColumn">Left Column Header:</label>
            <input type="text" id="statementColumn" data-update="statementColumn"
                   value="<?php echo esc($this->settings['statementColumn']); ?>">
        </div>

        <div class="form-group">
            <label for="scaleColumn">Right Column Header:</label>
            <input type="text" id="scaleColumn" data-update="scaleColumn"
                   value="<?php echo esc($this->settings['scaleColumn']); ?>">
        </div>

        <hr>

        <div class="form-group">
            <label for="statement1">Statement 1:</label>
            <input type="text" id="statement1" data-update="statement1"
                   value="<?php echo esc($this->settings['statement1']); ?>">
        </div>
        <div class="form-group">
            <label for="statement2">Statement 2:</label>
            <input type="text" id="statement2" data-update="statement2"
                   value="<?php echo esc($this->settings['statement2']); ?>">
        </div>
        <div class="form-group">
            <label for="statement3">Statement 3:</label>
            <input type="text" id="statement3" data-update="statement3"
                   value="<?php echo esc($this->settings['statement3']); ?>">
        </div>
        <div class="form-group">
            <label for="statement4">Statement 4:</label>
            <input type="text" id="statement4" data-update="statement4"
                   value="<?php echo esc($this->settings['statement4']); ?>">
        </div>

        <?php
        return ob_get_clean();
    }
}
