<?php
// modules/ParagraphInput.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class ParagraphInput {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        // Use a unique id if not provided
        $this->instanceId = $instanceId ?: uniqid('paragraphInput_');
        // Default settings merged with custom settings
        $this->settings = array_merge([
            'buttonName'   => 'Paragraph Input',
            'headingText'  => 'As a final exercise, please write out the insights and conclusions you reached through this process.',
            'userContent'  => '',
            'editorHeight' => '500' // New default for editor height (in pixels)
        ], $settings);
    }

    /**
     * Renders the module onto the canvas.
     * Displays a heading and a large TinyMCE editor directly in the preview.
     */
    public function render() {
        ob_start(); ?>

        <div class="module-preview paragraph-input-module"
             data-module="ParagraphInput"
             data-module-id="<?php echo esc($this->instanceId); ?>">
            
            <!-- Load TinyMCE from CDN if needed -->
            <script src="https://cdn.tiny.cloud/1/no-api-key/tinymce/6/tinymce.min.js" referrerpolicy="origin"></script>
            
            <style>
                .paragraph-input-container {
                    max-width: 800px;
                    margin: 20px auto;
                    font-family: Arial, sans-serif;
                    color: #333;
                    text-align: center;
                }
                .paragraph-input-container h2 {
                    font-size: 20px;
                    font-weight: normal;
                    margin-bottom: 16px;
                }
                /* Editor wrapper mimics a large input box */
                .paragraph-editor {
                    margin: 20px 0;
                    border: 1px solid #ccc;
                    border-radius: 6px;
                    overflow: hidden;
                    background: #fff;
                }
                /* Ensure the textarea fills the container */
                .paragraph-editor textarea {
                    width: 100%;
                    min-height: 400px;
                    box-sizing: border-box;
                }
            </style>

            <div class="paragraph-input-container">
                <!-- Heading Text -->
                <h2><?php echo esc($this->settings['headingText']); ?></h2>

                <!-- Textarea to be replaced by TinyMCE -->
                <div class="paragraph-editor">
                    <textarea id="paragraphEditor_<?php echo esc($this->instanceId); ?>">
<?php echo esc($this->settings['userContent']); ?>
                    </textarea>
                </div>
            </div>
            
            <!-- Initialize TinyMCE on the textarea -->
            <script>
            document.addEventListener('DOMContentLoaded', function() {
                var editorId = 'paragraphEditor_<?php echo esc($this->instanceId); ?>';
                // Remove any existing instance to avoid duplicates
                var existingEditor = tinymce.get(editorId);
                if (existingEditor) {
                    existingEditor.remove();
                }
                tinymce.init({
                    selector: '#' + editorId,
                    menubar: false,
                    height: <?php echo esc($this->settings['editorHeight']); ?>,
                    plugins: 'lists link code',
                    toolbar: 'undo redo | styleselect | bold italic underline | bullist numlist | link code',
                    setup: function(editor) {
                        editor.on('init', function() {
                            console.log("TinyMCE initialized for ParagraphInput <?php echo esc($this->instanceId); ?>");
                        });
                    }
                });
            });
            </script>
        </div>

        <?php
        return ob_get_clean();
    }

    /**
     * Renders the sidebar button for module selection.
     */
    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="ParagraphInput">'
             . esc($this->settings['buttonName'])
             . '</button>';
    }

    /**
     * Renders the settings panel.
     * Now includes a control for Editor Height and omits initial content.
     */
    public function renderSettings() {
        ob_start(); ?>
        
        <div class="form-group">
            <label for="headingText">Heading Text:</label>
            <input type="text" id="headingText" data-update="headingText"
                   value="<?php echo esc($this->settings['headingText']); ?>">
        </div>
        
        <div class="form-group">
            <label for="editorHeight">Editor Height (px):</label>
            <input type="number" id="editorHeight" data-update="editorHeight"
                   value="<?php echo esc($this->settings['editorHeight']); ?>" style="width:100px;">
        </div>
        
        <?php
        return ob_get_clean();
    }
}
?>
