<?php
namespace App\Controllers;

class AppBuilder extends BaseController
{
    public function index()
    {
        $modulesDir = APPPATH . 'Modules/';
        $moduleFiles = glob($modulesDir . '*.php');
        $moduleMarkup = [];
        $modules = [];
        $moduleSettingsMarkup = [];

        $pageBreakCounter = 1; // Counter for passing to renderSettings (NOT affecting the key)

        foreach ($moduleFiles as $file) {
            require_once $file;
            $moduleName = basename($file, '.php');

            if (class_exists($moduleName)) {
                $moduleInstance = new $moduleName();

                // Store the preview render HTML
                $moduleMarkup[$moduleName] = $moduleInstance->render();

                // Store module button info for the sidebar
                $modules[] = [
                    'name' => $moduleName,
                    'buttonName' => $moduleInstance->settings['buttonName'] ?? $moduleName,
                    'position' => $moduleInstance->settings['buttonPosition'] ?? 999,
                ];

                // If the module has a settings renderer, capture the output
                if (method_exists($moduleInstance, 'renderSettings')) {
                    // Only pass the page number if it's a PageBreak
                    if ($moduleName === 'PageBreak') {
                        $moduleSettingsMarkup[$moduleName] = $moduleInstance->renderSettings($pageBreakCounter);
                        $pageBreakCounter++;
                    } else {
                        $moduleSettingsMarkup[$moduleName] = $moduleInstance->renderSettings();
                    }
                }
            }
        }

        // Sort the modules by their button position
        usort($modules, fn($a, $b) => $a['position'] <=> $b['position']);

        // Pass all collected data to the view
        return view('app_builder_ui', [
            'modules' => $modules,
            'moduleMarkup' => $moduleMarkup,
            'moduleSettingsMarkup' => $moduleSettingsMarkup
        ]);
    }

    public function saveApp()
    {
        $request = $this->request->getJSON();
        log_message('debug', 'saveApp Request: ' . print_r($request, true));

        $appName = trim($request->appName);
        $appSlug = trim($request->appSlug);
        $modules = $request->modules;

        if (empty($appName) || empty($appSlug)) {
            return $this->response->setJSON([
                "success" => false,
                "message" => "Application name and URL slug are required."
            ]);
        }

        $appModel = new \App\Models\AppModel();

        if ($appModel->where('slug', $appSlug)->first()) {
            return $this->response->setJSON([
                "success" => false,
                "message" => "This URL slug is already taken."
            ]);
        }

        $data = [
            'name' => $appName,
            'slug' => $appSlug,
            'modules' => json_encode($modules),
            'created_at' => date("Y-m-d H:i:s")
        ];

        $insertID = $appModel->insert($data);

        if (!$insertID) {
            log_message('error', 'Failed to insert app data: ' . print_r($appModel->errors(), true));
            return $this->response->setJSON([
                "success" => false,
                "message" => "Failed to save application data."
            ]);
        }

        return $this->response->setJSON(["success" => true, "insertID" => $insertID]);
    }

    public function loadApp($appSlug)
    {
        $appModel = new \App\Models\AppModel();
        $appData = $appModel->where('slug', $appSlug)->first();

        if (!$appData) {
            return $this->response->setJSON([
                "success" => false,
                "message" => "Application not found."
            ]);
        }

        $appData['modules'] = json_decode($appData['modules'], true);
        return view('loaded_app', ["appData" => $appData]);
    }

    public function testInsert()
    {
        $appModel = new \App\Models\AppModel();
        $data = [
            'name' => 'Complex Test App',
            'slug' => 'complex-test-app',
            'modules' => json_encode([]),
            'created_at' => date("Y-m-d H:i:s")
        ];
        $insertID = $appModel->insert($data);
        echo $insertID ? "Inserted record ID: " . $insertID : "Insertion failed: " . print_r($appModel->errors(), true);
    }
    
    
public function update_module()
{
    $request = $this->request->getJSON(true);
    $moduleType = $request['moduleType'] ?? null;
    $instanceId = $request['instanceId'] ?? '';
    $settings = $request['settings'] ?? [];

    if (!$moduleType) {
        return $this->response->setJSON(['error' => 'No module type provided']);
    }

    // Build expected path to module PHP file
    $modulePath = APPPATH . 'Modules/' . $moduleType . '.php';

    // Check if the file exists
    if (!file_exists($modulePath)) {
        return $this->response->setJSON(['error' => 'Module file not found: ' . $modulePath]);
    }

    // Require the module class
    require_once $modulePath;

    // Now check if the class is available
    if (!class_exists($moduleType)) {
        return $this->response->setJSON(['error' => 'Class not found after loading: ' . $moduleType]);
    }

    try {
        $module = new $moduleType($instanceId, $settings);

        return $this->response->setJSON([
            'preview' => $module->render(),
            'settings' => $module->renderSettings()
        ]);
    } catch (\Throwable $e) {
        return $this->response->setJSON([
            'error' => 'Module render failed: ' . $e->getMessage()
        ]);
    }
}

    
    
}
