document.addEventListener('DOMContentLoaded', function () {
    const settingsPanel = document.getElementById('settings-pane');
    const canvas = document.getElementById('canvas');

    // Clear selection state
    function clearSelections() {
        document.querySelectorAll('.module-preview').forEach(mod => mod.classList.remove('selected'));
    }

    // Load module settings from predefined markup
    function loadModuleSettings(module, moduleType, moduleId) {
        settingsPanel.innerHTML = '<h2>Module Settings</h2>';

        const settingsHTML = moduleSettingsMarkup[moduleType];
        if (settingsHTML) {
            settingsPanel.innerHTML += settingsHTML;

            // Grab the visible page name text from the canvas module
            const currentPageName = module.querySelector('.dynamic-page-name')?.textContent.trim() || 'Untitled';

            // Set the correct data-target-module-id passed from the canvas click
            const input = settingsPanel.querySelector('.page-name-input');
            if (input) {
                input.value = currentPageName;
                input.setAttribute('data-target-module-id', moduleId);
            }

            settingsPanel.innerHTML += `<button id="save-module-settings">Update Module</button>`;
            document.getElementById('save-module-settings').onclick = function () {
                updateModuleFromSettings(module, moduleType);
            };

            // Bind modal trigger to the settings panel's content textarea only
            const contentInput = settingsPanel.querySelector('textarea[data-update="content"]');
            if (contentInput) {
                contentInput.readOnly = true; // Prevent inline editing
                contentInput.addEventListener('click', function (e) {
                    e.stopPropagation();
                    console.log("Settings panel content textarea clicked. Opening TinyMCE modal.");
                    openTinyMCEModal(contentInput.value, function(updatedContent) {
                        console.log("Modal returned updated content:", updatedContent);
                        contentInput.value = updatedContent;
                        // Update the live module preview, if a module is selected
                        const selectedModule = document.querySelector('.module-preview.selected');
                        if (selectedModule) {
                            const textEl = selectedModule.querySelector('.text-container p');
                            if (textEl) {
                                textEl.innerHTML = updatedContent;
                                console.log("Module preview updated with new content.");
                            } else {
                                console.warn("No text element found in the selected module.");
                            }
                        } else {
                            console.warn("No module selected; cannot update preview.");
                        }
                    });
                });
            }
        } else {
            settingsPanel.innerHTML += '<p>No settings defined for this module.</p>';
        }
    }

    // Apply changes dynamically to the selected module
    function applySettingToModule(module, setting, value) {
        const textContainer = module.querySelector('.text-container');
        if (!textContainer) return;

        if (setting === "content") {
            textContainer.querySelector('p').innerHTML = value;
        } else {
            textContainer.style[setting] = value;
        }
    }

    // Detect clicks on modules and load settings
    canvas.addEventListener('click', function (e) {
        const clickedModule = e.target.closest('.module-preview');
        if (clickedModule) {
            document.querySelectorAll('.module-preview').forEach(m => m.classList.remove('selected'));
            clickedModule.classList.add('selected');

            const moduleType = clickedModule.getAttribute('data-module');
            const moduleId = clickedModule.getAttribute('data-module-id');

            loadModuleSettings(clickedModule, moduleType, moduleId);
        } else {
            console.warn('Cannot edit — module is not placed in the canvas.');
            settingsPanel.innerHTML = '<h2>Module Settings</h2><p>Select a module from the canvas to edit.</p>';
        }
    });
});

// Global input listener for debugging page-name-input updates
document.addEventListener('input', function (e) {
    if (e.target.classList.contains('page-name-input')) {
        console.log('INPUT detected:', e.target);
        const moduleId = e.target.getAttribute('data-target-module-id');
        console.log('Target Module ID:', moduleId);
        const newName = e.target.value;
        console.log('New Name Typed:', newName);
        const moduleEl = document.querySelector(`.module-preview[data-module-id="${moduleId}"]`);
        console.log('Matched Module in Canvas:', moduleEl);
        if (moduleEl) {
            const nameEl = moduleEl.querySelector('.dynamic-page-name');
            console.log('Span to Update:', nameEl);
            if (nameEl) {
                nameEl.textContent = newName;
                console.log('Updated Canvas Text!');
            }
            moduleEl.setAttribute('data-page-name', newName);
        } else {
            console.warn('Module not found for ID:', moduleId);
        }
    }
});

console.log('Module Settings JS Loaded and Global Listener is Installed');
