<?php
if (function_exists('opcache_reset')) { opcache_reset(); }
error_reporting(E_ALL);
ini_set('display_errors', 1);
session_cache_limiter('nocache');
header("Cache-Control: no-cache, no-store, must-revalidate");
header("Pragma: no-cache");
header("Expires: 0");

if (!function_exists('base_url')) {
    function base_url($path = '') {
        $protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off') ? "https://" : "http://";
        $host = $_SERVER['HTTP_HOST'];
        $scriptDir = rtrim(dirname($_SERVER['SCRIPT_NAME']), '/\\');
        return $protocol . $host . $scriptDir . '/' . ltrim($path, '/');
    }
}

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

require_once __DIR__ . '/autoload.php';
$modulesDir = __DIR__ . '/modules/';
$moduleFiles = glob($modulesDir . '*.php');
$moduleMarkup = [];
$modules = [];

foreach ($moduleFiles as $file) {
    require_once $file;
    $moduleName = basename($file, '.php');
    if (class_exists($moduleName)) {
        $moduleInstance = new $moduleName();
        $moduleMarkup[$moduleName] = $moduleInstance->render();
        $modules[] = [
            'name' => $moduleName,
            'buttonName' => $moduleInstance->settings['buttonName'] ?? $moduleName,
            'position' => $moduleInstance->settings['buttonPosition'] ?? 999,
        ];
    }
}
usort($modules, fn($a, $b) => $a['position'] <=> $b['position']);
?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<title>App Creator Dashboard</title>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate">
<meta http-equiv="Pragma" content="no-cache">
<meta http-equiv="Expires" content="0">
<link href="https://fonts.googleapis.com/css?family=Roboto:400,500,700&display=swap" rel="stylesheet">
<link rel="stylesheet" href="<?php echo esc(base_url('assets/css/app_styles.css')); ?>?v=<?php echo time(); ?>">
<link href="https://fonts.googleapis.com/css2?family=Cinzel:wght@600&display=swap" rel="stylesheet">
<link rel="stylesheet" href="<?php echo esc(base_url('assets/css/modules.css')); ?>?v=<?php echo time(); ?>">
</head>

<body>

<div class="top-bar">
    <h1>App Creator Dashboard</h1>
    <div class="app-info">
        <input type="text" id="app-name" placeholder="App Name">
        <input type="text" id="app-slug" placeholder="App Slug">
        <button id="saveApp" class="btn save-btn">Save Application</button>
    </div>
    <div class="controls">
        <button class="btn undo-btn">Undo</button>
        <button class="btn redo-btn">Redo</button>
    </div>
</div>

<div id="app-builder">
    <div class="sidebar">
        <h2>Modules</h2>
        <ul>
            <?php foreach ($modules as $mod): ?>
                <li>
                    <button class="module-selector-btn" 
                            data-module="<?php echo esc($mod['name']); ?>" 
                            draggable="true"
                            onmouseover="showModulePreview('<?php echo esc($mod['name']); ?>', this)"
                            onmouseout="hideModulePreview()">
                        <?php echo esc($mod['buttonName']); ?>
                    </button>
                </li>
            <?php endforeach; ?>
        </ul>
    </div>

    <div class="canvas" id="canvas">
        <h2>Your App Preview</h2>
    </div>

    <div class="settings" id="settings-pane">
        <div id="settings-content">
            <p>Select a module to edit its settings.</p>
        </div>
    </div>
</div>

<!-- ✅ TinyMCE Modal -->
<div id="tinymceModal" style="position: fixed; top: 0; left: 0; right: 0; bottom: 0; background: rgba(0, 0, 0, 0.7); display: none; align-items: center; justify-content: center; z-index: 9999;">
    <div style="background: #fff; padding: 20px; width: 70%; max-width: 800px; border-radius: 8px; position: relative;">
        <textarea id="tinymceEditor" style="width: 100%; height: 300px;"></textarea>
        <div style="margin-top: 15px; text-align: right;">
            <button id="saveTinyContent" style="background-color: #2c3e8f; color: #fff; padding: 10px 20px; border: none; border-radius: 4px;">Save</button>
            <button id="cancelTinyContent" style="margin-left: 10px; padding: 10px 20px; border: 1px solid #ccc; border-radius: 4px;">Cancel</button>
        </div>
    </div>
</div>

<!-- ✅ Floating Hover Preview -->
<div id="module-preview-popup" 
     style="display:none; position:absolute; background:#fff; border:1px solid #ccc; 
            padding:10px; z-index:1000; max-width:400px; 
            box-shadow:0 2px 8px rgba(0,0,0,0.3); border-radius:8px;">
</div>

<!-- ✅ TinyMCE & Core JS -->
<script src="https://main.winslowapps.com/js/tinymce/tinymce.min.js"></script>

<script>
const moduleMarkup = <?php echo json_encode($moduleMarkup); ?>;

const moduleSettingsMarkup = {
<?php foreach ($moduleFiles as $file): 
    require_once $file;
    $moduleName = basename($file, '.php');
    if (class_exists($moduleName)) {
        $instance = new $moduleName();
        echo '"' . esc($moduleName) . '": ' . (method_exists($instance, 'renderSettings') ? json_encode($instance->renderSettings()) : 'null') . ',';
    }
endforeach; ?>
};

let tinyCallback = null;
function openTinyModal(content, callback) {
    tinyCallback = callback;
    document.getElementById('tinymceModal').style.display = 'flex';
    tinymce.init({
        selector: '#tinymceEditor',
        menubar: false,
        height: 300,
        plugins: 'link lists code',
        toolbar: 'undo redo | bold italic underline | bullist numlist | alignleft aligncenter alignright | link | code',
        setup: function (editor) { editor.on('init', () => editor.setContent(content)); }
    });
}

document.addEventListener('DOMContentLoaded', () => {
    document.getElementById('saveTinyContent')?.addEventListener('click', () => {
        const content = tinymce.get('tinymceEditor').getContent();
        if (tinyCallback) tinyCallback(content);
        tinymce.get('tinymceEditor').destroy();
        document.getElementById('tinymceModal').style.display = 'none';
    });

    document.getElementById('cancelTinyContent')?.addEventListener('click', () => {
        tinymce.get('tinymceEditor').destroy();
        document.getElementById('tinymceModal').style.display = 'none';
    });
});

// ✅ Hover Preview Logic
function showModulePreview(moduleName, buttonEl) {
    const previewEl = document.getElementById('module-preview-popup');
    const html = moduleMarkup[moduleName];
    if (!html) return;
    previewEl.innerHTML = html;
    previewEl.style.display = 'block';
    previewEl.style.top = (buttonEl.getBoundingClientRect().bottom + window.scrollY + 10) + 'px';
    previewEl.style.left = (buttonEl.getBoundingClientRect().right + window.scrollX + 10) + 'px';
}
function hideModulePreview() {
    document.getElementById('module-preview-popup').style.display = 'none';
}
</script>

<!-- ✅ Core Logic -->
<script src="<?php echo esc(base_url('assets/js/settings-panel.js')); ?>?v=<?php echo time(); ?>"></script>
<script src="<?php echo esc(base_url('assets/js/module-builder.js')); ?>?v=<?php echo time(); ?>"></script>
<script src="<?php echo esc(base_url('assets/js/app-saver.js')); ?>?v=<?php echo time(); ?>"></script>
<script src="<?php echo esc(base_url('assets/js/module-settings.js')); ?>?v=<?php echo time(); ?>"></script>

</body>
</html>
