document.addEventListener('DOMContentLoaded', () => {
  const formPreview = document.getElementById('formPreview');
  const rightSidebar = document.getElementById('rightSidebar');
  const sidebarInstructions = document.getElementById('sidebarInstructions');
  const elementOptionsContainer = document.getElementById('elementOptionsContainer');
  const addOptionButton = document.getElementById('addOptionButton');
  const addOptionValueCheckbox = document.getElementById('addOptionValue');
  let selectedElement = null;

  // ------------------------
  // OPTION ROW MANAGEMENT
  // ------------------------

  // Create an option row. If the checkbox is checked, include a second input.
  function createOptionRow(optionText = '', optionValue = '') {
    const row = document.createElement('div');
    row.className = 'option-row flex items-center gap-2 mb-1';
    const textInput = document.createElement('input');
    textInput.type = 'text';
    textInput.className = 'option-text border p-1 flex-grow';
    textInput.placeholder = 'Option text';
    textInput.value = optionText;
    textInput.addEventListener('input', updateOptionsLive);
    row.appendChild(textInput);
    if (addOptionValueCheckbox.checked) {
      const valueInput = document.createElement('input');
      valueInput.type = 'text';
      valueInput.className = 'option-value border p-1 flex-grow';
      valueInput.placeholder = 'Option value';
      valueInput.value = optionValue;
      valueInput.addEventListener('input', updateOptionsLive);
      row.appendChild(valueInput);
    }
    const removeBtn = document.createElement('button');
    removeBtn.textContent = 'Remove';
    removeBtn.className = 'ml-2 text-red-500 text-sm';
    removeBtn.addEventListener('click', (e) => {
      e.stopPropagation();
      row.remove();
      updateOptionsLive();
    });
    row.appendChild(removeBtn);
    return row;
  }

  // Load options from the selected element into the sidebar.
  function loadOptionsToSidebar() {
    elementOptionsContainer.innerHTML = '';
    if (!selectedElement) return;
    const type = selectedElement.getAttribute('data-type');
    if (type !== 'dropdown' && type !== 'radio' && type !== 'checkbox') return;
    const elementWrapper = selectedElement.querySelector('.editable-element-wrapper');
    let options = [];
    if (type === 'dropdown') {
      options = Array.from(elementWrapper.querySelectorAll('option')).map(opt => {
        return { text: opt.textContent.trim(), value: opt.value || '' };
      });
    } else {
      // For radio/checkbox groups, extract from labels.
      options = Array.from(elementWrapper.querySelectorAll('label')).map(lbl => {
        // Expect format: "Option Text (Option Value)" if applicable.
        const txt = lbl.textContent.trim();
        const match = txt.match(/^(.*?)(?:\s*\((.*?)\))?$/);
        return { text: match[1].trim(), value: (match[2] || '').trim() };
      });
    }
    options.forEach(opt => {
      const row = createOptionRow(opt.text, opt.value);
      elementOptionsContainer.appendChild(row);
    });
  }

  // Update the selected element's options based on sidebar rows.
  function updateOptionsLive() {
    if (!selectedElement) return;
    const type = selectedElement.getAttribute('data-type');
    const wrapper = selectedElement.querySelector('.editable-element-wrapper');
    const rows = elementOptionsContainer.querySelectorAll('.option-row');
    let options = [];
    rows.forEach(row => {
      const text = row.querySelector('.option-text').value.trim();
      let value = '';
      if (addOptionValueCheckbox.checked) {
        value = row.querySelector('.option-value').value.trim();
      }
      if (text !== '' || value !== '') {
        options.push({ text, value });
      }
    });
    // Update the selected element's options live.
    if (type === 'dropdown') {
      const select = wrapper.querySelector('select');
      if (select) {
        select.innerHTML = '';
        options.forEach(opt => {
          const optElem = document.createElement('option');
          optElem.textContent = opt.text;
          if (addOptionValueCheckbox.checked && opt.value !== '') {
            optElem.value = opt.value;
          }
          select.appendChild(optElem);
        });
      }
    } else if (type === 'radio' || type === 'checkbox') {
      wrapper.innerHTML = '';
      options.forEach((opt, index) => {
        const lbl = document.createElement('label');
        lbl.className = 'block';
        const inp = document.createElement('input');
        inp.type = type;
        inp.name = `${type}Group`;
        inp.value = index;
        lbl.appendChild(inp);
        const span = document.createElement('span');
        span.textContent = opt.text;
        lbl.appendChild(span);
        if (addOptionValueCheckbox.checked && opt.value !== '') {
          const valueSpan = document.createElement('span');
          valueSpan.textContent = ` (${opt.value})`;
          lbl.appendChild(valueSpan);
        }
        wrapper.appendChild(lbl);
      });
    }
  }

  // When the plus button is clicked, add a new empty option row
  addOptionButton.addEventListener('click', (e) => {
    e.stopPropagation();
    // Check if the last row is nonempty; if empty, do nothing.
    const rows = elementOptionsContainer.querySelectorAll('.option-row');
    if (rows.length > 0) {
      const lastRow = rows[rows.length - 1];
      const lastText = lastRow.querySelector('.option-text').value.trim();
      let lastValue = '';
      if (addOptionValueCheckbox.checked) {
        lastValue = lastRow.querySelector('.option-value').value.trim();
      }
      if (lastText === '' && lastValue === '') {
        return;
      }
    }
    const newRow = createOptionRow();
    elementOptionsContainer.appendChild(newRow);
    updateOptionsLive();
  });

  // When the "Add Value Column" checkbox changes, reload option rows.
  addOptionValueCheckbox.addEventListener('change', () => {
    if (selectedElement) {
      loadOptionsToSidebar();
      updateOptionsLive();
    }
  });

  // ------------------------
  // ELEMENT CONTAINER MANAGEMENT
  // ------------------------

  // Add move and delete controls to an element container.
function addMoveDeleteControls(container) {
    const controlsDiv = document.createElement('div');
    controlsDiv.className = 'absolute top-2 right-2 flex gap-2 items-center bg-white p-1 rounded shadow';

    // Move Up Button
    const moveUpBtn = document.createElement('button');
    moveUpBtn.textContent = '↑';
    moveUpBtn.className = 'text-blue-500 text-sm p-1 border border-blue-500 rounded hover:bg-blue-100';
    moveUpBtn.addEventListener('click', (e) => {
        e.stopPropagation();
        if (container.previousElementSibling) {
            container.parentNode.insertBefore(container, container.previousElementSibling);
        }
    });

    // Move Down Button
    const moveDownBtn = document.createElement('button');
    moveDownBtn.textContent = '↓';
    moveDownBtn.className = 'text-blue-500 text-sm p-1 border border-blue-500 rounded hover:bg-blue-100';
    moveDownBtn.addEventListener('click', (e) => {
        e.stopPropagation();
        if (container.nextElementSibling) {
            container.parentNode.insertBefore(container.nextElementSibling, container);
        }
    });

    // Delete Button
    const deleteBtn = document.createElement('button');
    deleteBtn.textContent = '✖';
    deleteBtn.className = 'text-red-500 text-sm p-1 border border-red-500 rounded hover:bg-red-100';
    deleteBtn.addEventListener('click', (e) => {
        e.stopPropagation();
        container.remove();
        if (selectedElement === container) {
            selectedElement = null;
            sidebarInstructions.style.display = 'block';
            clearSidebar();
        }
    });

    controlsDiv.appendChild(moveUpBtn);
    controlsDiv.appendChild(moveDownBtn);
    controlsDiv.appendChild(deleteBtn);
    container.appendChild(controlsDiv);
}


  // Create a container for a form element.
  function createElementContainer(type, contentHTML) {
    const container = document.createElement('div');
    container.className = 'element-container border border-dashed mb-4 relative p-2';
    container.setAttribute('data-type', type);
    container.setAttribute('data-content', contentHTML);

    // Create a label element.
    const label = document.createElement('label');
    label.className = 'block font-semibold text-sm mb-1';
    label.textContent = 'Label';
    container.appendChild(label);

    // Create an inner wrapper for the element.
    const elementWrapper = document.createElement('div');
    elementWrapper.className = 'editable-element-wrapper';
    elementWrapper.innerHTML = contentHTML;
    
    container.appendChild(elementWrapper);



    // Create a tooltip element.
    const tooltip = document.createElement('span');
    tooltip.className = 'absolute right-2 top-2 text-gray-500 text-xs hidden';
    tooltip.textContent = '?';
    container.appendChild(tooltip);

    // Add move and delete controls.
    addMoveDeleteControls(container);

    // Click event: load properties into the sidebar.
    container.addEventListener('click', (e) => {
    e.stopPropagation();
    selectedElement = container;
    sidebarInstructions.style.display = 'none';

    console.log("Clicked element:", selectedElement); // Debug log
    console.log("Element type:", container.getAttribute('data-type')); // Log the data-type

    // Check if this is a Title Page
    if (container.getAttribute('data-type') === 'title') {
        console.log("✅ Title Page Clicked - Switching to Title Editor");

        // ✅ Hide Default Editor, Show Title Editor
        document.getElementById('defaultEditor').style.display = 'none';
        document.getElementById('titleEditor').style.display = 'block';

        // ✅ Load the Title Page content into the sidebar fields
        document.getElementById('titleTextEditor').value =
          container.querySelector('.title-text')?.textContent || '';

        document.getElementById('titleSubtitle').value =
          container.querySelector('.subtitle-text')?.textContent || '';

        document.getElementById('titleAuthor').value =
          container.querySelector('.author-text')?.textContent || '';

    } else {
        console.log("✅ Non-Title Element Clicked - Switching to Default Editor");

        // ✅ Show Default Editor, Hide Title Editor
        document.getElementById('defaultEditor').style.display = 'block';
        document.getElementById('titleEditor').style.display = 'none';

        // ✅ Load default element properties (Margins, Padding, Tooltip, etc.)
        document.getElementById('elementLabel').value = container.querySelector('label')?.textContent || '';
        document.getElementById('elementTooltip').value = container.querySelector('span')?.textContent || '';

        const elementWrapper = container.querySelector('.editable-element-wrapper');
        if (elementWrapper) {
            document.getElementById('marginTop').value = parseInt(elementWrapper.style.marginTop) || 10;
            document.getElementById('marginRight').value = parseInt(elementWrapper.style.marginRight) || 10;
            document.getElementById('marginBottom').value = parseInt(elementWrapper.style.marginBottom) || 10;
            document.getElementById('marginLeft').value = parseInt(elementWrapper.style.marginLeft) || 10;
            document.getElementById('paddingTop').value = parseInt(elementWrapper.style.paddingTop) || 10;
            document.getElementById('paddingRight').value = parseInt(elementWrapper.style.paddingRight) || 10;
            document.getElementById('paddingBottom').value = parseInt(elementWrapper.style.paddingBottom) || 10;
            document.getElementById('paddingLeft').value = parseInt(elementWrapper.style.paddingLeft) || 10;

            const inputField = elementWrapper.querySelector('input, textarea');
            document.getElementById('elementPlaceholder').value = inputField ? inputField.getAttribute('placeholder') : '';
        }

        // ✅ Load options if applicable
        const type = container.getAttribute('data-type');
        if (type === 'dropdown' || type === 'radio' || type === 'checkbox') {
            loadOptionsToSidebar();
        } else {
            elementOptionsContainer.innerHTML = '';
        }
    }
});

    return container;
  }

  // Add a new element to the preview.
  function addElement(type, defaultHTML) {
    const container = createElementContainer(type, defaultHTML);
    formPreview.appendChild(container);
  }



  
  
// RIGHT SIDE MOVE, DELETE LISTENERS

// Ensure the right sidebar buttons exist
const moveUpSidebarBtn = document.getElementById('moveUp');
const moveDownSidebarBtn = document.getElementById('moveDown');
const removeSidebarBtn = document.getElementById('deleteElement');

// Move element UP
moveUpSidebarBtn.addEventListener('click', (e) => {
    e.stopPropagation();
    if (selectedElement) {
        const previousElement = selectedElement.previousElementSibling;

        // Prevent moving above the title (check if previous sibling is an <h2>)
        if (previousElement && !previousElement.classList.contains('form-preview-title')) {
            selectedElement.parentNode.insertBefore(selectedElement, previousElement);
        }
    }
});


// Move element DOWN
moveDownSidebarBtn.addEventListener('click', (e) => {
    e.stopPropagation();
    if (selectedElement && selectedElement.nextElementSibling) {
        selectedElement.parentNode.insertBefore(selectedElement.nextElementSibling, selectedElement);
    }
});

// REMOVE element
removeSidebarBtn.addEventListener('click', (e) => {
    e.stopPropagation();
    if (selectedElement) {
        selectedElement.remove();
        selectedElement = null;
        sidebarInstructions.style.display = 'block'; // Show instructions again
        clearSidebar(); // Reset right panel
    }
});

// TITLE PAGE

document.getElementById('addTitlePage').addEventListener('click', () => {
  // Create the container
  const container = document.createElement('div');
  container.className = 'element-container border border-gray-300 bg-white shadow-lg mx-auto text-center relative flex flex-col items-center justify-center';
  container.style.fontFamily = "'Times New Roman', serif";
  
  // Mark this container as a title page
  container.setAttribute('data-type', 'title');

  // Set width to 100% for full preview
  container.style.width = '100%';

  // Append container to formPreview
  document.getElementById('formPreview').appendChild(container);

  // Set height to maintain 16:9 aspect ratio
  const containerWidth = container.clientWidth;
  container.style.height = (containerWidth * (9 / 16)) + 'px';

  // Add Delete Button (stays always visible in the corner)
  const deleteButton = document.createElement('button');
  deleteButton.textContent = '✖';
  deleteButton.className = 'absolute top-2 right-2 bg-red-500 text-white px-2 py-1 text-sm rounded shadow hover:bg-red-700';
  deleteButton.style.cursor = 'pointer';
  deleteButton.addEventListener('click', (e) => {
    e.stopPropagation();
    container.remove();
  });
  container.appendChild(deleteButton);

  // ----- Logo Upload Section with Updated Behavior -----
  const logoWrapper = document.createElement('div');
  logoWrapper.className = 'mb-4 flex flex-col items-center relative';

  // File input (visible initially if no logo exists)
  const logoInput = document.createElement('input');
  logoInput.type = 'file';
  logoInput.className = 'block mx-auto mb-2';
  logoInput.accept = 'image/*';
  logoInput.style.display = 'block'; // Visible initially

  // Logo preview image (hidden initially)
  const logoPreview = document.createElement('img');
  logoPreview.className = 'mx-auto mb-4 w-32 h-32 object-contain';
  logoPreview.style.borderRadius = '50%';
  logoPreview.style.display = 'none'; // Hidden initially

  // Remove Logo button (hidden initially)
  const removeLogoBtn = document.createElement('button');
  removeLogoBtn.textContent = 'Remove Logo';
  removeLogoBtn.className = 'absolute top-0 right-0 bg-red-500 text-white text-xs px-2 py-1 rounded';
  removeLogoBtn.style.cursor = 'pointer';
  removeLogoBtn.style.display = 'none'; // Hidden initially

  // When a file is selected, load the logo
  logoInput.addEventListener('change', (e) => {
    const file = e.target.files[0];
    if (file) {
      const reader = new FileReader();
      reader.onload = (event) => {
        logoPreview.src = event.target.result;
        logoPreview.style.display = 'block'; // Show the logo preview
        logoInput.style.display = 'none';    // Hide the file input ("Browse")
      };
      reader.readAsDataURL(file);
    }
  });

  // When hovering over the logo, show the remove button
  logoWrapper.addEventListener('mouseenter', () => {
    if (logoPreview.style.display !== 'none') {
      removeLogoBtn.style.display = 'block';
    }
  });
  logoWrapper.addEventListener('mouseleave', () => {
    removeLogoBtn.style.display = 'none';
  });

  // When the remove button is clicked, remove the logo and show the input again
  removeLogoBtn.addEventListener('click', () => {
    logoPreview.src = '';
    logoPreview.style.display = 'none';
    removeLogoBtn.style.display = 'none';
    logoInput.style.display = 'block';
    // Also reset the file input value so you can re-upload the same file if needed
    logoInput.value = '';
  });

  // Append logo upload elements to the logoWrapper
  logoWrapper.appendChild(logoInput);
  logoWrapper.appendChild(logoPreview);
  logoWrapper.appendChild(removeLogoBtn);
  // ---------------------------------------------------------

  // Decorative Line (Above Title)
  const lineTop = document.createElement('div');
  lineTop.className = 'mx-auto my-4';
  lineTop.style.width = '60%';
  lineTop.style.height = '4px';
  lineTop.style.background = 'linear-gradient(to right, transparent, gold, transparent)';

  // Title Input
  const titleInput = document.createElement('input');
  titleInput.type = 'text';
  titleInput.className = 'block w-full text-5xl font-bold text-blue-900 text-center bg-transparent border-none outline-none';
  titleInput.style.fontFamily = "'Times New Roman', serif";
  titleInput.placeholder = 'Enter Title';

  // Subtitle Input
  const subtitleInput = document.createElement('input');
  subtitleInput.type = 'text';
  subtitleInput.className = 'block w-full text-2xl italic text-yellow-600 text-center bg-transparent border-none outline-none';
  subtitleInput.placeholder = 'Enter Subtitle';

  // Decorative Line (Below Subtitle)
  const lineBottom = document.createElement('div');
  lineBottom.className = 'mx-auto my-4';
  lineBottom.style.width = '60%';
  lineBottom.style.height = '4px';
  lineBottom.style.background = 'linear-gradient(to right, transparent, gold, transparent)';

  // Author Input
  const authorInput = document.createElement('input');
  authorInput.type = 'text';
  authorInput.className = 'block w-full text-lg text-gray-800 text-center bg-transparent border-none outline-none';
  authorInput.placeholder = 'Enter Author Name';

  // Append the Title Page elements to the container
  container.appendChild(logoWrapper);
  container.appendChild(lineTop);
  container.appendChild(titleInput);
  container.appendChild(subtitleInput);
  container.appendChild(lineBottom);
  container.appendChild(authorInput);
});



// Add the other event listeners outside the TITLE PAGE block.
  // For Text Field
  document.getElementById('addText').addEventListener('click', (e) => {
    e.stopPropagation();
    addElement('text', '<input type="text" class="w-full p-2 border rounded" placeholder="Text Field">');
  });

  // For Dropdown
  document.getElementById('addDropdown').addEventListener('click', (e) => {
    e.stopPropagation();
    addElement('dropdown', '<select class="w-full p-2 border rounded"><option>Option 1</option></select>');
  });

  // For Radio Group
  document.getElementById('addRadio').addEventListener('click', (e) => {
    e.stopPropagation();
    addElement('radio', '<div><label><input type="radio" name="radioGroup"> Option 1</label></div>');
  });

  // For Checkbox
  document.getElementById('addCheckbox').addEventListener('click', (e) => {
    e.stopPropagation();
    addElement('checkbox', '<div><label><input type="checkbox" name="checkboxGroup"> Option 1</label></div>');
  });



// ------------------------
// RIGHT SIDEBAR: Live Updates for Margins/Paddings
// ------------------------
const marginTopInput = document.getElementById('marginTop');
const marginRightInput = document.getElementById('marginRight');
const marginBottomInput = document.getElementById('marginBottom');
const marginLeftInput = document.getElementById('marginLeft');
const paddingTopInput = document.getElementById('paddingTop');
const paddingRightInput = document.getElementById('paddingRight');
const paddingBottomInput = document.getElementById('paddingBottom');
const paddingLeftInput = document.getElementById('paddingLeft');

function updateMarginPadding() {
  if (!selectedElement) return;

  // Apply margin & padding to the entire element-container (label + field)
  selectedElement.style.marginTop = marginTopInput.value + 'px';
  selectedElement.style.marginRight = marginRightInput.value + 'px';
  selectedElement.style.marginBottom = marginBottomInput.value + 'px';
  selectedElement.style.marginLeft = marginLeftInput.value + 'px';
  selectedElement.style.paddingTop = paddingTopInput.value + 'px';
  selectedElement.style.paddingRight = paddingRightInput.value + 'px';
  selectedElement.style.paddingBottom = paddingBottomInput.value + 'px';
  selectedElement.style.paddingLeft = paddingLeftInput.value + 'px';
}

// Attach event listeners to margin & padding inputs
marginTopInput.addEventListener('input', updateMarginPadding);
marginRightInput.addEventListener('input', updateMarginPadding);
marginBottomInput.addEventListener('input', updateMarginPadding);
marginLeftInput.addEventListener('input', updateMarginPadding);
paddingTopInput.addEventListener('input', updateMarginPadding);
paddingRightInput.addEventListener('input', updateMarginPadding);
paddingBottomInput.addEventListener('input', updateMarginPadding);
paddingLeftInput.addEventListener('input', updateMarginPadding);


  // ------------------------
  // RIGHT SIDEBAR: Live Updates for Label, Tooltip, Placeholder
  // ------------------------
  const elementLabelInput = document.getElementById('elementLabel');
  const elementTooltipInput = document.getElementById('elementTooltip');
  const elementPlaceholderInput = document.getElementById('elementPlaceholder');

  elementLabelInput.addEventListener('input', () => {
    if (selectedElement) {
      selectedElement.querySelector('label').textContent = elementLabelInput.value;
    }
  });
  elementTooltipInput.addEventListener('input', () => {
    if (selectedElement) {
      const tooltipEl = selectedElement.querySelector('span');
      if (elementTooltipInput.value) {
        tooltipEl.textContent = elementTooltipInput.value;
        tooltipEl.classList.remove('hidden');
      } else {
        tooltipEl.classList.add('hidden');
      }
    }
  });
  elementPlaceholderInput.addEventListener('input', () => {
    if (selectedElement) {
      const inputField = selectedElement.querySelector('.editable-element-wrapper input, .editable-element-wrapper textarea');
      if (inputField) {
        inputField.setAttribute('placeholder', elementPlaceholderInput.value);
      }
    }
  });
});
