// ✅ Make clearSelections global
function clearSelections() {
  document.querySelectorAll('.module-preview').forEach(m => m.classList.remove('selected'));
}


document.addEventListener('DOMContentLoaded', function () {
    const canvas = document.getElementById('canvas');
    const moduleButtons = document.querySelectorAll('.sidebar .module-selector-btn');

    // Set up event listeners for sidebar module buttons (click & dragstart)
    moduleButtons.forEach(button => {
        button.addEventListener('click', function () {
            const moduleType = button.getAttribute('data-module');
            console.log("Module button clicked for:", moduleType);
            addModuleToCanvas(moduleType);
        });
        button.addEventListener('dragstart', function (e) {
            const moduleType = e.target.getAttribute('data-module');
            e.dataTransfer.setData('text/plain', moduleType);
            e.dataTransfer.effectAllowed = 'copy';
            console.log("Drag started for module:", moduleType);
        });
    });

    // Set up drag & drop on the canvas
    canvas.addEventListener('dragover', function (e) {
        e.preventDefault();
        e.dataTransfer.dropEffect = 'copy';
    });

    canvas.addEventListener('drop', function (e) {
        e.preventDefault();
        const moduleType = e.dataTransfer.getData('text/plain');
        console.log("Module dropped:", moduleType, "at Y =", e.clientY);
        addModuleToCanvas(moduleType, e.clientY);
    });

    // ✅ Function to add a module to the canvas
    function addModuleToCanvas(moduleType, dropY = null) {
        console.log("Attempting to add module:", moduleType);
        if (!moduleMarkup[moduleType]) {
            console.warn(`No markup found for module type: ${moduleType}`);
            return;
        }
        const tempDiv = document.createElement('div');
        tempDiv.innerHTML = moduleMarkup[moduleType].trim();
        const moduleEl = tempDiv.firstElementChild;
        if (!moduleEl) {
            console.error(`Error creating module element for: ${moduleType}`);
            return;
        }
        moduleEl.classList.add('module-preview');

        const innerPreview = moduleEl.querySelector('.module-preview');
        if (innerPreview) innerPreview.remove();

        const deleteIcon = document.createElement('div');
        deleteIcon.className = 'delete-icon';
        deleteIcon.innerHTML = '&times;';
        deleteIcon.style.cursor = 'pointer';
        deleteIcon.onclick = function () {
            moduleEl.remove();
            updatePageNumbers();
        };
        moduleEl.appendChild(deleteIcon);

        // Handle dropping location
        if (dropY !== null) {
            let inserted = false;
            const existingModules = Array.from(canvas.querySelectorAll('.module-preview'));
            for (let mod of existingModules) {
                const rect = mod.getBoundingClientRect();
                if (dropY < rect.top + rect.height / 2) {
                    canvas.insertBefore(moduleEl, mod);
                    inserted = true;
                    console.log(`Inserted module ${moduleType} before an existing module.`);
                    break;
                }
            }
            if (!inserted) {
                canvas.appendChild(moduleEl);
                console.log(`Appended module ${moduleType} to the end of canvas.`);
            }
        } else {
            canvas.appendChild(moduleEl);
            console.log(`Appended module ${moduleType} to the canvas.`);
        }

        clearSelections();
        moduleEl.classList.add('selected');

        // ✅ Load dynamic settings panel for this module
        window.loadModuleSettings(moduleEl);

        updatePageNumbers();
    }

    // ✅ Click handler for selecting modules on the canvas
    canvas.addEventListener('click', function (e) {
        const clickedModule = e.target.closest('.module-preview');
        if (clickedModule) {
            clearSelections();
            clickedModule.classList.add('selected');

            // ✅ Load dynamic settings for selected module
            window.loadModuleSettings(clickedModule);
        }
    });


    // MutationObserver to update page numbering and button labels whenever modules change
    const observer = new MutationObserver(updatePageNumbers);
    observer.observe(canvas, { childList: true, subtree: true });

    // Initial update call
    updatePageNumbers();
});

/** ✅ Update dynamic page numbering and navigation button labels for PageBreak modules */
function updatePageNumbers() {
    const pageBreaks = document.querySelectorAll('.canvas .page-break-module');

    pageBreaks.forEach((module, index) => {
        const nextButton = module.querySelector('[data-page-btn]');
        const prevButton = module.querySelector('[data-prev-btn]');
        const saveButton = module.querySelector('[data-save-btn]');

        // 🔥 Set NEXT button text based on position
        if (nextButton) {
            if (index === 0) {
                nextButton.textContent = 'Begin';
            } else if (index === pageBreaks.length - 1) {
                nextButton.textContent = 'Submit';
            } else {
                nextButton.textContent = 'Next';
            }
        }

        // 🔥 Show or hide PREVIOUS button
        if (prevButton) {
            prevButton.style.display = (index === 0) ? 'none' : 'inline-block';
        }

        // 🔥 Hide Save for Later button on first page
        if (saveButton) {
            saveButton.style.display = (index === 0) ? 'none' : 'inline-block';
        }

        // Optional: Dynamic page number display if needed
        const pageNumberSpan = module.querySelector('.dynamic-page-number');
        if (pageNumberSpan) {
            pageNumberSpan.textContent = index + 1;
        }
    });
}



// ✅ Global Module Helper Functions

// Store module settings globally by instanceId
window.moduleSettings = window.moduleSettings || {};

/**
 * Get saved settings for a module instance
 */
function getModuleSettings(instanceId) {
  return window.moduleSettings[instanceId] || {};
}

/**
 * Update settings for a module and optionally trigger re-render
 */
function updateModuleSettings(instanceId, newSettings, fullRender = true) {
  window.moduleSettings[instanceId] = newSettings;

  if (!fullRender) {
    updateModulePreviewOnly(instanceId);
    return;
  }

  const moduleEl = document.querySelector(`[data-module-id="${instanceId}"]`);
  if (!moduleEl) return;

  const moduleType = moduleEl.getAttribute('data-module');

  console.log("🔥 renderModule called for:", instanceId);
  console.log("📡 Sending updated settings to server for", moduleType, newSettings);

  fetch('/app-builder/update_module', {
    method: 'POST',
    headers: { 'Content-Type': 'application/json' },
    body: JSON.stringify({
      moduleType,
      instanceId,
      settings: newSettings
    })
  })
    .then(res => res.json())
.then(data => {
  if (data.error) {
    console.error("❌ Server error:", data.error);
    return;
  }

  // ✅ Replace module preview in the canvas
  const wrapper = document.createElement('div');
  wrapper.innerHTML = data.preview.trim();
  const newModule = wrapper.firstElementChild;
  moduleEl.replaceWith(newModule);

  // ✅ Reselect the newly inserted module
  clearSelections();
  newModule.classList.add('selected');

  // ✅ Re-render the correct settings panel immediately
  window.loadModuleSettings(newModule);

  console.log("✅ Module re-rendered and settings panel loaded.");
});

}



/**
 * Lightweight refresh of module preview only
 */
function updateModulePreviewOnly(instanceId) {
  renderModule(instanceId); // Could later be more efficient
}

/**
 * render function – 
 */
function renderModule(instanceId) {
  console.log("🔥 renderModule called for:", instanceId);

  const settings = getModuleSettings(instanceId);
  const moduleEl = document.querySelector(`[data-module-id="${instanceId}"]`);
  if (!moduleEl) {
    console.warn("❌ Could not find module element for:", instanceId);
    return;
  }

  const moduleType = moduleEl.getAttribute('data-module');
  if (!moduleType) {
    console.warn("❌ Could not determine module type.");
    return;
  }

  console.log("📡 Sending updated settings to server for", moduleType, settings);

  fetch('/update-module', {
    method: 'POST',
    headers: { 'Content-Type': 'application/json' },
    body: JSON.stringify({
      moduleType,
      instanceId,
      settings
    })
  })
    .then(res => res.json())
    .then(data => {
      if (data.error) {
        console.error("❌ Server error:", data.error);
        return;
      }

      // Replace module preview in canvas
      const tempPreview = document.createElement('div');
      tempPreview.innerHTML = data.preview.trim();
      const newModule = tempPreview.firstElementChild;
      if (newModule) {
        moduleEl.replaceWith(newModule);
        console.log("✅ Preview replaced for", instanceId);
      } else {
        console.warn("⚠️ Failed to parse preview HTML");
      }

      // Replace settings panel content
const settingsPane = document.getElementById('settings-content');
if (settingsPane) {
  settingsPane.innerHTML = data.settings;
  console.log("✅ Settings panel updated for", instanceId);
  initSettingsJS(); // ✅ Rebind all events
}

    })
    .catch(err => {
      console.error("🔥 AJAX update failed:", err);
    });
}



/** ✅ Called after replacing settings panel */
function initSettingsJS() {
  console.log("🔁 Reinitializing settings JS...");

  // ✅ Generic binding for any [data-setting] inputs across all modules
  document.querySelectorAll('.module-settings [data-setting]').forEach(input => {
    const container = input.closest('.module-settings');
    if (!container) return;

    const instanceId = container?.id?.replace(/^.*?_/, ''); // removes module prefix like 'paragraphScripture_'
    const setting = input.getAttribute('data-setting');
    if (!instanceId || !setting) return;

    // Optional: log for debugging focus
    input.addEventListener('focus', () => {
      console.log(`👁 Focused input for [${setting}] in ${instanceId}`);
    });

    // Handle real-time typing
    input.addEventListener('input', () => {
      const settings = getModuleSettings(instanceId);
      settings[setting] = input.value;
      console.log(`📝 Updated setting: [${setting}] = ${input.value}`);
      updateModuleSettings(instanceId, settings);
    });

    // Optional: separate listener for <select> or blur updates
    input.addEventListener('change', () => {
      const settings = getModuleSettings(instanceId);
      settings[setting] = input.value;
      console.log(`📤 Change committed: [${setting}] = ${input.value}`);
      updateModuleSettings(instanceId, settings);
    });
  });

  // ✅ MultiParagraph-specific bindings (unchanged)
  document.querySelectorAll('.add-multi-paragraph-row').forEach(button => {
    button.addEventListener('click', function () {
      const container = button.closest('.module-settings');
      const instanceId = container?.id.replace('multiParagraphSettings_', '');
      const settings = getModuleSettings(instanceId);
      if (!Array.isArray(settings.rows)) settings.rows = [];
      const newRow = { label: 'New Row Label', description: 'Optional description' };
      settings.rows.push(newRow);
      console.log("➕ Adding row:", newRow);
      updateModuleSettings(instanceId, settings);
    });
  });

  document.querySelectorAll('.remove-multi-paragraph-row').forEach(button => {
    button.addEventListener('click', function () {
      const container = button.closest('.module-settings');
      const rowId = parseInt(button.dataset.rowId, 10);
      const instanceId = container?.id.replace('multiParagraphSettings_', '');
      const settings = getModuleSettings(instanceId);
      if (!Array.isArray(settings.rows)) settings.rows = [];
      settings.rows.splice(rowId, 1);
      console.log("🗑 Removing row", rowId);
      updateModuleSettings(instanceId, settings);
    });
  });

  document.querySelectorAll('.multi-paragraph-label-input').forEach(input => {
    input.addEventListener('input', function () {
      const container = input.closest('.module-settings');
      const rowId = parseInt(input.dataset.rowId, 10);
      const field = input.dataset.setting;
      const instanceId = container?.id.replace('multiParagraphSettings_', '');
      const settings = getModuleSettings(instanceId);
      if (!Array.isArray(settings.rows)) settings.rows = [];
      settings.rows[rowId][field] = input.value;
      console.log(`✏️ Updated row ${rowId} field '${field}' to:`, input.value);
      updateModuleSettings(instanceId, settings);
    });
  });
}

