<?php
// modules/ScoreSummary.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class ScoreSummary {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        // Generate a unique ID if none is provided
        $this->instanceId = $instanceId ?: uniqid('scoreSummary_');

        // Merge default settings with any passed in
        $this->settings = array_merge([
            'buttonName'    => 'Score Summary',
            // Main question or heading
            'headingText'   => 'Which type of spiritual identity do you primarily carry: an orphan or a son?',
            // Score label and default value
            'scoreLabel'    => 'Your total score (out of 105):',
            'scoreValue'    => '95',
            // Scoring Ranges heading and defaults
            'rangeHeading'  => 'Scoring Ranges:',
            'range1Min'     => '21',
            'range1Max'     => '42',
            'range1Label'   => 'Spirit of an Orphan',
            'range2Min'     => '43',
            'range2Max'     => '83',
            'range2Label'   => 'A Season of Spiritual Transition',
            'range3Min'     => '84',
            'range3Max'     => '105',
            'range3Label'   => 'Spirit of a Son',
            // Placeholder: selected modules to sum
            'selectedModules' => [],
        ], $settings);
    }

    /**
     * Renders a styled summary of the user's total score,
     * along with scoring ranges, at about double the original size,
     * using 75% of the container width and centered.
     */
    public function render() {
        ob_start(); ?>
        
        <div class="module-preview score-summary-module"
             data-module="ScoreSummary"
             data-module-id="<?php echo esc($this->instanceId); ?>">

            <!-- Inline CSS with doubled sizing, 75% width, centered -->
            <style>
                .score-summary-container {
                    width: 50%;           /* Use 75% of the container width */
                    margin: 0 auto;       /* Center the container */
                    font-family: Arial, sans-serif;
                    color: #333;
                }
                .score-question {
                    font-weight: normal;
                    font-size: 32px;      /* Double the original ~16px */
                    margin: 32px 0;       
                }
                .score-label {
                    font-weight: bold;
                    font-size: 32px;      
                }
                .score-line {
                    display: flex;
                    align-items: center;
                    margin-bottom: 32px;  
                }
                .score-line .score-label {
                    margin-right: 16px;   
                }
                .score-box {
                    display: inline-block;
                    padding: 8px 24px;    
                    border: 1px solid #ccc;
                    border-radius: 8px;   
                    font-weight: bold;
                    background: #fff;
                    min-width: 80px;      
                    text-align: center;
                    font-size: 28px;      
                }
                .scoring-heading {
                    margin-top: 48px;     
                    font-size: 32px;      
                    font-weight: bold;
                }
                .range-item {
                    margin: 16px 0;       
                    font-size: 28px;      
                }
            </style>

            <div class="score-summary-container">
                <!-- Main question/heading -->
                <div class="score-question">
                    <?php echo esc($this->settings['headingText']); ?>
                </div>

                <!-- Score label and box -->
                <div class="score-line">
                    <div class="score-label">
                        <?php echo esc($this->settings['scoreLabel']); ?>
                    </div>
                    <div class="score-box">
                        <?php echo esc($this->settings['scoreValue']); ?>
                    </div>
                </div>

                <!-- Scoring ranges heading -->
                <div class="scoring-heading">
                    <?php echo esc($this->settings['rangeHeading']); ?>
                </div>

                <!-- List out each range -->
                <div class="range-item">
                    <?php echo esc($this->settings['range1Min']); ?> -
                    <?php echo esc($this->settings['range1Max']); ?>:
                    <?php echo esc($this->settings['range1Label']); ?>
                </div>
                <div class="range-item">
                    <?php echo esc($this->settings['range2Min']); ?> -
                    <?php echo esc($this->settings['range2Max']); ?>:
                    <?php echo esc($this->settings['range2Label']); ?>
                </div>
                <div class="range-item">
                    <?php echo esc($this->settings['range3Min']); ?> -
                    <?php echo esc($this->settings['range3Max']); ?>:
                    <?php echo esc($this->settings['range3Label']); ?>
                </div>
            </div>
        </div>
        
        <?php
        return ob_get_clean();
    }

    /**
     * Renders the sidebar button for module selection.
     */
    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="ScoreSummary">'
             . esc($this->settings['buttonName'])
             . '</button>';
    }

    /**
     * Renders the settings panel for this module.
     */
    public function renderSettings() {
        ob_start(); ?>

        <div class="form-group">
            <label for="headingText">Heading/Question:</label>
            <input type="text" id="headingText" data-update="headingText"
                   value="<?php echo esc($this->settings['headingText']); ?>">
        </div>

        <div class="form-group">
            <label for="scoreLabel">Score Label:</label>
            <input type="text" id="scoreLabel" data-update="scoreLabel"
                   value="<?php echo esc($this->settings['scoreLabel']); ?>">
        </div>

        <hr>

        <div class="form-group">
            <label for="rangeHeading">Scoring Ranges Heading:</label>
            <input type="text" id="rangeHeading" data-update="rangeHeading"
                   value="<?php echo esc($this->settings['rangeHeading']); ?>">
        </div>

        <div class="form-group">
            <label>Range 1:</label>
            <div style="display:flex; gap:6px;">
                <input type="text" data-update="range1Min" 
                       value="<?php echo esc($this->settings['range1Min']); ?>" style="width:50px;">
                <span>-</span>
                <input type="text" data-update="range1Max" 
                       value="<?php echo esc($this->settings['range1Max']); ?>" style="width:50px;">
                <input type="text" data-update="range1Label" 
                       value="<?php echo esc($this->settings['range1Label']); ?>" style="flex:1;">
            </div>
        </div>

        <div class="form-group">
            <label>Range 2:</label>
            <div style="display:flex; gap:6px;">
                <input type="text" data-update="range2Min" 
                       value="<?php echo esc($this->settings['range2Min']); ?>" style="width:50px;">
                <span>-</span>
                <input type="text" data-update="range2Max" 
                       value="<?php echo esc($this->settings['range2Max']); ?>" style="width:50px;">
                <input type="text" data-update="range2Label" 
                       value="<?php echo esc($this->settings['range2Label']); ?>" style="flex:1;">
            </div>
        </div>

        <div class="form-group">
            <label>Range 3:</label>
            <div style="display:flex; gap:6px;">
                <input type="text" data-update="range3Min" 
                       value="<?php echo esc($this->settings['range3Min']); ?>" style="width:50px;">
                <span>-</span>
                <input type="text" data-update="range3Max" 
                       value="<?php echo esc($this->settings['range3Max']); ?>" style="width:50px;">
                <input type="text" data-update="range3Label" 
                       value="<?php echo esc($this->settings['range3Label']); ?>" style="flex:1;">
            </div>
        </div>

        <hr>

        <!-- Placeholder: selecting modules to sum. Currently does nothing. -->
        <div class="form-group">
            <label>Select Modules to Sum:</label><br>
            <small>These controls are placeholders for future functionality.</small>
            <div style="margin-top:8px;">
                <label>
                    <input type="checkbox" data-update="selectedModules" value="Likert1">
                    Likert 1
                </label><br>
                <label>
                    <input type="checkbox" data-update="selectedModules" value="Likert2">
                    Likert 2
                </label><br>
                <label>
                    <input type="checkbox" data-update="selectedModules" value="Likert3">
                    Likert 3
                </label><br>
                <label>
                    <input type="checkbox" data-update="selectedModules" value="Likert4">
                    Likert 4
                </label><br>
                <label>
                    <input type="checkbox" data-update="selectedModules" value="Likert5">
                    Likert 5
                </label>
            </div>
        </div>

        <?php
        return ob_get_clean();
    }
}
